#
# spec file for package python-PyQt6-sip
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
# Check PyPI for version: https://pypi.org/project/PyQt6-sip/
Name:           python-PyQt6-sip
Version:        13.10.2
Release:        1.1
Summary:        The sip module support for PyQt6
License:        BSD-2-Clause
URL:            https://github.com/Python-SIP/sip
Source0:        https://files.pythonhosted.org/packages/source/P/PyQt6-sip/pyqt6_sip-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
The sip extension module provides support for the PyQt6 package.

SIP is a tool for automatically generating Python bindings for
C and C++ libraries. SIP was originally developed in 1998 for
PyQt - the Python bindings for the Qt GUI toolkit - but is
suitable for generating bindings for any C or C++ library. SIP
can also be used write self contained extension modules, i.e.
without a library to be wrapped.

%prep
%autosetup -p1 -n pyqt6_sip-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license LICENSE
%dir %{python_sitearch}/PyQt6
%{python_sitearch}/PyQt6/sip*
%{python_sitearch}/[Pp]y[Qq]t6_sip-%{version}.dist-info

%changelog
* Mon Jun  9 2025 Ben Greiner <code@bnavigator.de>
- Update to 13.10.2
  * Match python3-sip6-devel 6.11.1
  * Changes WRT PEP 639. See python-sip6
* Fri Apr  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Support older and current versions of setuptools WRT to the case of
  the metadata directory.
* Thu Apr  3 2025 Ben Greiner <code@bnavigator.de>
- Update to 13.10.0
  * New ABI version 13.10
  * Match python3-sip6-devel 6.10
  * Drop fix-license-in-setup_py.patch
* Tue Jan 21 2025 Antonio Larrosa <alarrosa@suse.com>
- Change license to just BSD-2-Clause. Since all files are using
  this license and it's the only LICENSE file included I contacted
  upstream (Phil Thompson) and he confirmed that it's licensed
  just as BSD-2-Clause and setup.py needs fixing, so I added the
  following patch to change it:
  * fix-license-in-setup_py.patch
* Wed Jan  8 2025 Ben Greiner <code@bnavigator.de>
- Update to 13.9.1
  * New ABI version 13.9
  * Match python3-sip6-devel 6.9.1+
* Tue Oct 15 2024 Fabian Vogt <fvogt@suse.com>
- Update to ABI version 13.8.0
  * Match python3-sip6-devel 6.8.6+
  * Is now BSD-2-Clause licensed
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Drop support-python3.6.patch
  * python-foo prefixed packages for SLE15 with python3.6 should be
    handled by an SLE internal maintenance request to python3-foo
* Wed Oct 18 2023 llyyr <llyyr.public@gmail.com>
- Update to ABI version 13.6.0
  * Properly fix the Python v3.12 support by deprecating
    sipPyTypeDict() and adding sipPyTypeDictRef().
* Wed Sep 27 2023 Ben Greiner <code@bnavigator.de>
- Update to ABI version 13.5.2
  * Match python-sip6-devel 6.7.10+
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Apr 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 13.5.1
  * Fixed the new handling of ctors with /Transfer/ annotated
    arguments.
* Tue Mar 14 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to support Python 3.6 in order to build for
  SLE/Leap 15:
  * support-python3.6.patch
* Sun Jan 29 2023 Ben Greiner <code@bnavigator.de>
- Upate to ABI version 13.4.1
  * am_send, wt_reserve
* Mon Jun 20 2022 Ben Greiner <code@bnavigator.de>
- Update to ABI version 13.4.0
  * The array type is now accessible from the sip module.
* Wed Apr 13 2022 Ben Greiner <code@bnavigator.de>
- Update to ABI version 13.3.1
- Support for Python 3.6 has been dropped
* Sat Feb  5 2022 Ben Greiner <code@bnavigator.de>
- Update to ABI version 13.2.1
  * fix in objmap
* Fri Dec  3 2021 Ben Greiner <code@bnavigator.de>
- Update to ABI version 13.2.0
  * no release notes other than those from SIP 6.5.0
* Thu May 13 2021 Ben Greiner <code@bnavigator.de>
- Update to version 13.1.0
* Fri Feb 19 2021 Ben Greiner <code@bnavigator.de>
- Initial specfile for version 13.0.1
